# Licensed Materials - Property of IBM
# 5724-M24
# Copyright IBM Corporation 2008, 2009. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# **************************************************************************
# Upgrade the Monitor configurations: 
#   - Upgrade all Alphablox cubes (6.1 only)
#   - Register all migrated models to Data Service Scheduler (6.1 only)
# **************************************************************************

# set WAS home
CUR_DIR=`pwd`
SH_R_DIR=`dirname ${0}`
cd "$SH_R_DIR/../../../"
WAS_HOME=`pwd`
export WAS_HOME
cd "$CUR_DIR"

WSADMIN_HOST=localhost
WSADMIN_PORT=8880
WSADMIN_CONN_TYPE=SOAP
WSADMIN_USER=user
WSADMIN_PASSWORD=password
WSADMIN_CLASSPATH=$WAS_HOME/plugins/com.ibm.wbimonitor.lifecycle.spi.jar

ABX_HOST=.
ABX_PORT=.
ABX_USER=.
ABX_PASSWORD=.

LOG_DIR=$WAS_HOME/logs/wbm/migration
if [ ! -d "$LOG_DIR" ]; then
	mkdir "$LOG_DIR"
fi
LOG_FILE=$LOG_DIR/monitor_configuration_upgrade_log.txt

echo "**************************************************************************"
echo "Upgrade the Monitor configurations from 6.x to 7.0"
echo "**************************************************************************"
echo "Please check the required wsadmin parameters defined in monConfigurationUpgrade.sh,"
echo "and they are used to connect to the Monitor server."
echo "  <WSADMIN_HOST>      = $WSADMIN_HOST"
echo "  <WSADMIN_PORT>      = $WSADMIN_PORT"
echo "  <WSADMIN_CONN_TYPE> = $WSADMIN_CONN_TYPE"
echo "  <WSADMIN_USER>      = $WSADMIN_USER"
echo "  <WSADMIN_PASSWORD>  = $WSADMIN_PASSWORD"
echo

echo "Please also check the optional Alphablox server configuration,"
echo "and the cubes on the default or specified Alphablox server will be upgraded."
echo "  <ABX_HOST>      = $ABX_HOST"
echo "  <ABX_PORT>      = $ABX_PORT"
echo "  <ABX_USER>      = $ABX_USER"
echo "  <ABX_PASSWORD>  = $ABX_PASSWORD"
echo
echo "  Usage 1: upgrade the cubes in the default Alphablox server which was specified in the Monitor database"
echo "     <ABX_HOST>      = ."
echo "     <ABX_PORT>      = ."
echo "     <ABX_USER>      = ."
echo "     <ABX_PASSWORD>  = ."
echo "  Usage 2: upgrade the cubes in the specified Alphablox server with security disabled"
echo "     <ABX_HOST>      = hostname or IP (e.g. localhost)"
echo "     <ABX_PORT>      = BOOTSTRAP_ADDRESS (e.g. 2809)"
echo "     <ABX_USER>      = ."
echo "     <ABX_PASSWORD>  = ."
echo "  Usage 3: upgrade the cubes in the specified Alphablox server with security enabled"
echo "     <ABX_HOST>      = hostname or IP (e.g. localhost)"
echo "     <ABX_PORT>      = BOOTSTRAP_ADDRESS (e.g. 2809)"
echo "     <ABX_USER>      = user"
echo "     <ABX_PASSWORD>  = password"

echo "Continue? [Input Y to continue or input N if you want to modify the listed parameters]:"
read para
if [ "$para" == "N" ] || [ "$para" == "n" ]; then 
	echo "Exit the program, and please edit the parameters in monConfigurationUpgrade.sh"
	exit
fi

echo
echo "Please input the version of the old Monitor[61 or 62]:"
read VERSION
while [ "$VERSION" != "61" ] && [ "$VERSION" != "62" ]
do
	echo "The version $VERSION is not supported , and please input 61 or 62."
	echo
	echo "Please input the version of the old Monitor[61 or 62]:"
	read VERSION
done

echo
echo "Start to upgrade the Monitor configurations, and after it's completed, you could check the log file: $LOG_FILE."

# **************************************************************************
# Upgrade the Alphablox cubes in the default Alphablox server 
# which was configured for each model version in the Monitor database
# **************************************************************************
if [ "$ABX_HOST" == "." ] && [ "$ABX_PORT" == "." ]; then
	"$WAS_HOME/bin/wsadmin.sh" -lang jython -conntype $WSADMIN_CONN_TYPE -host $WSADMIN_HOST -port $WSADMIN_PORT -user $WSADMIN_USER -password $WSADMIN_PASSWORD -wsadmin_classpath "$WSADMIN_CLASSPATH" -f monConfigurationUpgrade.jy $VERSION > "$LOG_FILE" 2>&1
	exit
fi


# **************************************************************************
# Upgrade the Alphablox cubes in the specified Alphablox server 
# which security is disabled
# **************************************************************************
if [ "$ABX_HOST" != "." ] && [ "$ABX_PORT" != "." ] && [ "$ABX_USER" == "." ] && [ "$ABX_PASSWORD" == "." ]; then
	"$WAS_HOME/bin/wsadmin.sh" -lang jython -conntype $WSADMIN_CONN_TYPE -host $WSADMIN_HOST -port $WSADMIN_PORT -user $WSADMIN_USER -password $WSADMIN_PASSWORD -wsadmin_classpath "$WSADMIN_CLASSPATH" -f monConfigurationUpgrade.jy $VERSION $ABX_HOST $ABX_PORT > "$LOG_FILE" 2>&1
	exit
fi


# **************************************************************************
# Upgrade the Alphablox cubes in the specified Alphablox server 
# which security is enabled
# **************************************************************************
if [ "$ABX_HOST" != "." ] && [ "$ABX_PORT" != "." ] && [ "$ABX_USER" != "." ] && [ "$ABX_PASSWORD" != "." ]; then
	"$WAS_HOME/bin/wsadmin.sh" -lang jython -conntype $WSADMIN_CONN_TYPE -host $WSADMIN_HOST -port $WSADMIN_PORT -user $WSADMIN_USER -password $WSADMIN_PASSWORD -wsadmin_classpath "$WSADMIN_CLASSPATH" -f monConfigurationUpgrade.jy $VERSION $ABX_HOST $ABX_PORT $ABX_USER $ABX_PASSWORD > "$LOG_FILE" 2>&1
	exit
fi


echo "Invalid Alphablox server configuration, and please edit them in monConfigurationUpgrade.sh"


